Learn R Programming

tidystats (version 0.3)

correlation_table: Create a correlation table

Description

Function to create a correlation table.

Usage

correlation_table(correlations, triangle = "lower", p_values = NULL,
  diagonal = NULL, labels = NULL, digits = 2)

Arguments

correlations

A data frame or matrix containing the correlations.

triangle

A character string indicating whether the lower, upper, or both halves should be visible, must be one of 'lower', 'upper', or 'both'. You can specify just the initial letter.

p_values

A data frame or matrix containing the p-values.

diagonal

A vector of values to be placed on the diagonal. Default is a vector of 1s.

labels

A vector of strings containing the labels for each variable.

digits

An integer indicating the number of decimal places.

Examples

Run this code
# NOT RUN {
# Add examples

# }

Run the code above in your browser using DataLab