inspect is a function to inspect one or more models that are part of a
tidystats list. The function will open a Shiny widget in the Viewer pane,
which will show the results of one or more models. This allows the user to
visually inspect the model output, as well as copy the results in APA format.
# S3 method for list
inspect(results, ...)A tidystats list.
Identifiers of models to show in the viewer.