Learn R Programming

tidystats (version 0.3)

read_stats: Read a .csv file that was produced with write_stats

Description

read_stats can convert a .csv file containing the statistical results that was produced with write_stats. It returns a list containing the results, with the identifier as the name for each list element.

Usage

read_stats(file)

Arguments

file

Path to the tidy stats data file

Examples

Run this code
# NOT RUN {
results <- read_stats(system.file("results.csv", package = "tidystats"))

# }

Run the code above in your browser using DataLab