Learn R Programming

tidystats (version 0.3)

rename_columns: Rename statistics columns

Description

Renames the statistics columns.

Usage

rename_columns(x)

Arguments

x

The output of a statistical model, converted to a data frame.

Details

This function matches each column name with an entry in a list of statistical names and renames the column if necessary. The goal is to create a naming scheme that makes statistical labels as consistent as possible.