Learn R Programming

tidystats (version 0.3)

report_anova: Report method for ANOVA models

Description

Function to report ANOVA output in APA style.

Usage

report_anova(identifier, group = NULL, term = NULL, term_nr = NULL,
  results = getOption("tidystats_list"))

Arguments

identifier

A character string identifying the model.

group

A character string indicating the group containing the statistics you want to report.

term

A character string indicating the term you want to report.

term_nr

A number indicating the term you want to report.

results

A tidystats list.

Examples

Run this code
# NOT RUN {
# Read in a list of results
results <- read_stats(system.file("results.csv", package = "tidystats"))

# Set the list as the default list
options(tidystats_list = results)

# Report results
report_anova("aov_two_way", term = "condition")
report_anova("aov_two_way", term = "sex")

# }

Run the code above in your browser using DataLab