Learn R Programming

tidystats (version 0.3)

report_correlation: Report function for correlations

Description

Function to report a correlation in APA style.

Usage

report_correlation(identifier, term, term_nr,
  results = getOption("tidystats_list"))

Arguments

identifier

A character string identifying the model.

term

A character string indicating the term you want to report.

term_nr

A number indicating the term you want to report.]

results

A tidystats list.

Examples

Run this code
# NOT RUN {
# Read in a list of results
results <- read_stats(system.file("results.csv", package = "tidystats"))

# Set the default tidystats list in options()
options(tidystats_list = results)

# Report results
report(identifier = "correlation_pearson")
report(identifier = "correlation_spearman")
report(identifier = "correlation_kendall")

# }

Run the code above in your browser using DataLab