Learn R Programming

tidystats (version 0.3)

report_glm: Report method for generalized linear models

Description

Function to report a generalized linear models in APA style.

Usage

report_glm(identifier, group = NULL, term = NULL, term_nr = NULL,
  results = getOption("tidystats_list"))

Arguments

identifier

A character string identifying the model.

group

A character string indicating the group containing the statistics you want to report.

term

A character string indicating the term you want to report.

term_nr

A number indicating the term you want to report.

results

A tidystats list.

Examples

Run this code
# NOT RUN {
# Read in a list of results
results <- read_stats(system.file("results.csv", package = "tidystats"))

# Set the default results list
options(tidystats_list = results)

# Report results
report("glm_gaussian", term = "Prewt")
report("glm_gamma", term = "log(u)")
report("glm_poisson", term_nr = 2)

# }

Run the code above in your browser using DataLab