Learn R Programming

tidystats (version 0.3)

report_lm: Report method for linear regression models

Description

Function to report a regression in APA style.

Usage

report_lm(identifier, group = NULL, term = NULL, term_nr = NULL,
  results = getOption("tidystats_list"))

Arguments

identifier

A character string identifying the model.

group

A character string indicating the group containing the statistics you want to report.

term

A character string indicating the term you want to report.

term_nr

A number indicating the term you want to report.

results

A tidystats list.

Examples

Run this code
# NOT RUN {
# Read in a list of results
results <- read_stats(system.file("results.csv", package = "tidystats"))

# Set the default results list
options(tidystats_list = results)

# Report results
report("lm_simple", term = "conditionmortality salience")
report("lm_simple", term_nr = 2)
report("lm_simple", group = "model")

# }

Run the code above in your browser using DataLab