Learn R Programming

tidystats (version 0.3)

report_lmm: Report method for linear mixed models

Description

Function to report a linear mixed model in APA style.

Usage

report_lmm(identifier, group = NULL, term = NULL, term_nr = NULL,
  results = getOption("tidystats_list"))

Arguments

identifier

A character string identifying the model.

group

A character string indicating the group containing the statistics you want to report.

term

A character string indicating the term you want to report.

term_nr

A number indicating the term you want to report.

results

A tidystats list.

Examples

Run this code
# NOT RUN {
# Read in a list of results
results <- read_stats(system.file("results.csv", package = "tidystats"))

# Set the default results list
options(tidystats_list = results)

# Example: regression term
report("lme4_lme", term = "Days")
report("lmerTest_lme", term = "Days")

# }

Run the code above in your browser using DataLab