Learn R Programming

tidystats (version 0.3)

report_rma: Report method for metafor's rma models

Description

Function to report a meta-analysis in APA style.

Usage

report_rma(identifier, group = NULL, term = NULL, term_nr = NULL,
  results = getOption("tidystats_list"))

Arguments

identifier

A character string identifying the model.

group

A character string identifying the group you want to report the statistics of.

term

A character string indicating which term you want to report the statistics of.

term_nr

A number indicating which term you want to report the the statistics of.

results

A tidystats list.