Learn R Programming

tidystats (version 0.3)

report_statistic: Report a single statistic

Description

A helper function to report single statistics in APA style.

Usage

report_statistic(statistic, value)

Arguments

statistic

A character string indicating the kind of statistic (e.g., p, t, df).

value

The value of the statistic to be reported.

Examples

Run this code
# NOT RUN {
report_statistic("p", 0.0001)
report_statistic("t", 4.2325)
report_statistic("r", 0.213)

# }

Run the code above in your browser using DataLab