Function create a table in order to display results of a regression.
report_table_lm(identifier, terms = NULL, term_nrs = NULL,
statistics = NULL, include_model = TRUE, term_labels = NULL,
results = getOption("tidystats_list"))A character string identifying the model.
A character vector indicating which terms you want to report in the table.
A numeric vector indicating which terms you want to report in the table.
A character vector of statistics you want to display in the table.
Include or exclude model statistics (e.g., R squared).
A character vector to change the labels for the terms.
A tidystats list.