Learn R Programming

tidystats (version 0.3)

report_wilcoxon: Report function for Wilcoxon Rank Sum and Signed Rank Tests

Description

Function to report Wilcoxon Rank Sum and Signed Rank Tests in APA style.

Usage

report_wilcoxon(identifier, results = getOption("tidystats_list"))

Arguments

identifier

A character string identifying the model.

results

A tidystats list.

Examples

Run this code
# NOT RUN {
# Read in a list of results
results <- read_stats(system.file("results.csv", package = "tidystats"))

# Set the default tidystats list in options()
options(tidystats_list = results)

# Report results
report(identifier = "wilcoxon_rank_sum")
report(identifier = "wilcoxon_signed_rank")

# }

Run the code above in your browser using DataLab