Learn R Programming

tidystats (version 0.3)

tidy_count_data: Convert count data to a tidy data frame

Description

tidy_count_data returns a tidy data frame of count statistics created with tidystats' count_data.

Usage

tidy_count_data(count_data)

Arguments

count_data

a data frame created with tidystats' count_data.

Examples

Run this code
# NOT RUN {
library(dplyr)

# Calculate counts
condition_n <- count_data(cox, condition)

# Create a tidy data frame of the count data
tidy_count_data(condition_n)

# With a grouping variable:
cox %>%
  group_by(sex) %>%
  count_data(condition) %>%
  tidy_count_data()

# }

Run the code above in your browser using DataLab