Learn R Programming

tidystats (version 0.3)

tidy_stats.aov: Create a tidy stats data frame from an aov object

Description

tidy_stats.aov takes an aov object and converts the object to a tidy stats data frame.

Usage

# S3 method for aov
tidy_stats(model)

Arguments

model

Output of aov without within-subject factors.

Examples

Run this code
# NOT RUN {
# Conduct an ANOVA
model_aov <- aov(yield ~ block + N * P * K, npk)

# Tidy stats
tidy_stats(model_aov)

# }

Run the code above in your browser using DataLab