Learn R Programming

tidystats (version 0.3)

tidy_stats.aovlist: Create a tidy stats data frame from an aovlist object

Description

tidy_stats.aovlist takes an aovlist object and converts the object to a tidy stats data frame.

Usage

# S3 method for aovlist
tidy_stats(model)

Arguments

model

Output of aov() including within-subject factors.

Examples

Run this code
# NOT RUN {
# Conduct a within-subjects ANOVA
model_aov_within <- aov(extra ~ group + Error(ID/group), data = sleep)

# Tidy stats
tidy_stats(model_aov_within)

# }

Run the code above in your browser using DataLab