Learn R Programming

tidystats (version 0.3)

tidy_stats.glm: Create a tidy stats data frame from a glm object

Description

tidy_stats.glm takes a glm object and converts the object to a tidy stats data frame.

Usage

# S3 method for glm
tidy_stats(model)

Arguments

model

Output of glm().

Examples

Run this code
# NOT RUN {
# Get data
counts <- c(18,17,15,20,10,20,25,13,12)
outcome <- gl(3,1,9)
treatment <- gl(3,3)
d.AD <- data.frame(treatment, outcome, counts)

# Run model
glm.D93 <- glm(counts ~ outcome + treatment, family = poisson())

# Tidy stats
tidy_stats(glm.D93)

# }

Run the code above in your browser using DataLab