Learn R Programming

tidystats (version 0.3)

tidy_stats.lm: Create a tidy stats data frame from an lm object

Description

tidy_stats.lm takes an lm object and converts the object to a tidy stats data frame.

Usage

# S3 method for lm
tidy_stats(model)

Arguments

model

Output of lm().

Examples

Run this code
# NOT RUN {
# Conduct a regression
ctl <- c(4.17,5.58,5.18,6.11,4.50,4.61,5.17,4.53,5.33,5.14)
trt <- c(4.81,4.17,4.41,3.59,5.87,3.83,6.03,4.89,4.32,4.69)
group <- gl(2, 10, 20, labels = c("Ctl","Trt"))
weight <- c(ctl, trt)

model_lm <- lm(weight ~ group)
tidy_stats(model_lm)

# }

Run the code above in your browser using DataLab