Learn R Programming

tidystats (version 0.3)

tidy_stats.lmerMod: Create a tidy stats data frame from an lmerMod object

Description

tidy_stats.lmerMod takes an lmerMod object and converts the object to a tidy stats data frame.

Usage

# S3 method for lmerMod
tidy_stats(model)

Arguments

model

Output of lme4's lmer().

Examples

Run this code
# NOT RUN {
  # Load package
  library(lme4)

  # Conduct a linear mixed model
  model_lmer <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)

  # Tidy stats
  tidy_stats(model_lmer)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab