Learn R Programming

tidystats (version 0.3)

tidy_stats.lmerModLmerTest: Create a tidy stats data frame from an lmerModLmerTest object

Description

tidy_stats.lmerModLmerTest takes an lmerModLmerTest object and converts the object to a tidy stats data frame.

Usage

# S3 method for lmerModLmerTest
tidy_stats(model)

Arguments

model

Output of lmerTest's lmer().

Examples

Run this code
# NOT RUN {
  # Load packages
  library(lme4)
  library(lmerTest)

  # Conduct a linear mixed model
  model_lmerTest <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)

  # Tidy stats
  tidy_stats(model_lmerTest)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab