Learn R Programming

tidystats (version 0.3)

tidy_stats.rma: Create a tidy stats data frame from an rma object from the metafor package

Description

tidy_stats.rma takes an rma object and converts the object to a tidy stats data frame.

Usage

# S3 method for rma
tidy_stats(model)

Arguments

model

Output of metafor::rma().