read_stats: Read a .csv file that was produced with write_stats
Description
read_stats can convert a .csv file containing the statistical results that was produced with write_stats. It returns a list containing the results, with the identifier as the name for each list element.