Function to report a meta-analysis in APA style.
report_rma(identifier, group = NULL, term = NULL, term_nr = NULL,
results = getOption("tidystats_list"))A character string identifying the model.
A character string identifying the group you want to report the statistics of.
A character string indicating which term you want to report the statistics of.
A number indicating which term you want to report the the statistics of.
A tidystats list.