powered by
A helper function to report single statistics in APA style.
report_statistic(statistic, value)
A character string indicating the kind of statistic (e.g., p, t, df).
The value of the statistic to be reported.
# NOT RUN { report_statistic("p", 0.0001) report_statistic("t", 4.2325) report_statistic("r", 0.213) # }
Run the code above in your browser using DataLab